@@ -5,7 +5,7 @@ import subprocess
 from configparser import ConfigParser
 from datetime import datetime, timezone
 from functools import cache
-from tempfile import TemporaryFile, TemporaryDirectory
+from tempfile import TemporaryDirectory
 from zipfile import ZipFile
 
 import click
@@ -58,7 +58,8 @@ def upload_submission_comments(submissions_dir, codeval_prefix):
 
 @click.command()
 @click.argument('codeval_dir', metavar="CODEVAL_DIR")
-@click.option("--submissions-dir", help="directory containing submissions COURSE/ASSIGNMENT/STUDENT_ID", default='./submissions', show_default=True)
+@click.option("--submissions-dir", help="directory containing submissions COURSE/ASSIGNMENT/STUDENT_ID",
+              default='./submissions', show_default=True)
 def evaluate_submissions(codeval_dir, submissions_dir):
     """
     Evaluate submissions stored in the form COURSE/ASSIGNMENT/STUDENT_ID.
@@ -101,9 +102,10 @@ def evaluate_submissions(codeval_dir, submissions_dir):
                     except Exception:
                         warn(f"could not parse compile timeout from {line}, using default {compile_timeout}")
                 if line.startswith("CD"):
-                    assignment_working_dir = os.path.normpath(os.path.join(assignment_working_dir, line.split()[1].strip()))
-                    if not os.path.exists(os.path.join(repo_dir, assignment_working_dir)):
-                        out = f"{assignment_working_dir} does not exist\n".encode('utf-8')
+                    assignment_working_dir = os.path.normpath(
+                        os.path.join(assignment_working_dir, line.split()[1].strip()))
+                    if not os.path.isdir(os.path.join(repo_dir, assignment_working_dir)):
+                        out = f"{assignment_working_dir} does not exist or is not a directory\n".encode('utf-8')
                         move_to_next_submission = True
                         break
                 if line.startswith("Z"):
@@ -114,7 +116,7 @@ def evaluate_submissions(codeval_dir, submissions_dir):
         if not move_to_next_submission:
             command = raw_command.replace("EVALUATE", "cd /submissions; assignment-codeval run-evaluation codeval.txt")
 
-            with TemporaryDirectory("cedir", dir="/var/tmp", delete=False) as link_dir:
+            with TemporaryDirectory("cedir", dir="/var/tmp") as link_dir:
                 repo_link = os.path.join(link_dir, "submissions")
                 os.symlink(repo_dir, repo_link)
                 full_assignment_working_dir = os.path.join(repo_link, assignment_working_dir)
@@ -147,11 +149,15 @@ def evaluate_submissions(codeval_dir, submissions_dir):
 @click.argument("course_name", metavar="COURSE")
 @click.argument("assignment_name", metavar="ASSIGNMENT")
 @click.option("--target-dir", help="directory to download submissions to", default='./submissions', show_default=True)
-@click.option("--include-commented", is_flag=True, help="even download submissionsthat already have codeval comments since last submission")
-@click.option("--uncommented_for", help="only download submission where the last comment is more than these minutes ago", default=0, show_default=True)
+@click.option("--include-commented", is_flag=True,
+              help="even download submissionsthat already have codeval comments since last submission")
+@click.option("--uncommented_for",
+              help="only download submission where the last comment is more than these minutes ago", default=0,
+              show_default=True)
 @click.option("--codeval-prefix", help="prefix for codeval comments", default="codeval: ", show_default=True)
 @click.option("--include-empty", is_flag=True, help="include empty submissions")
-def download_submissions(course_name, assignment_name, target_dir, include_commented, codeval_prefix, include_empty, uncommented_for):
+def download_submissions(course_name, assignment_name, target_dir, include_commented, codeval_prefix, include_empty,
+                         uncommented_for):
     """
     Download submissions for a given assignment in a course from Canvas.
 
@@ -174,7 +180,7 @@ def download_submissions(course_name, assignment_name, target_dir, include_comme
             last_comment_date = submission_comments[-1]
         else:
             last_comment_date = None
-        if not include_commented and last_comment_date and submission.submitted_at <= last_comment_date:
+        if not include_commented and last_comment_date and submission.submitted_at and submission.submitted_at <= last_comment_date:
             continue
 
         if uncommented_for > 0 and last_comment_date:
@@ -183,13 +189,15 @@ def download_submissions(course_name, assignment_name, target_dir, include_comme
             if delta.total_seconds() < uncommented_for * 60:
                 continue
 
-        student_id = submission.user['login_id']
+        student_id = str(submission.user_id)
+        student_name = submission.user['name']
         student_submission_dir = os.path.join(submission_dir, student_id)
         os.makedirs(student_submission_dir, exist_ok=True)
 
         metapath = os.path.join(student_submission_dir, "metadata.txt")
         with open(metapath, "w") as fd:
             print(f"""id={student_id}
+name={student_name}
 course={course.name}
 assignment={assignment.name}
 attempt={submission.attempt}
@@ -227,6 +235,6 @@ last_comment={last_comment_date}""", file=fd)
 def get_submissions_by_id(assignment):
     submissions_by_id = {}
     for submission in assignment.get_submissions(include=["user"]):
-        student_id = submission.user['login_id']
+        student_id = str(submission.user_id)
         submissions_by_id[student_id] = submission
-    return submissions_by_id
\ No newline at end of file
+    return submissions_by_id
